"""
    General Synthesis

    # General Synthesis Service for Electronic Lab Notebooks (ELN)  ## Setup  ### Python  Recommended:  - [pyenv](https://github.com/pyenv/pyenv) - to manage Python versions - [pyenv-virtualenv](https://github.com/pyenv/pyenv-virtualenv) - to manage virtual environments  ```sh pyenv install 3.9.10 pyenv virtualenv 3.9.10 gensyn-eln pyenv local gensyn-eln pip install --upgrade pip pip install -r requirements.txt ```  ## Running  Ensure Ray is running:  ```sh ray start --head ```  Run the service:  ```sh python src/main.py ```   # noqa: E501

    The version of the OpenAPI document: 0.0.1
    Contact: info@general-synthesis.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import gensyn_client
from gensyn_client.model.random_type import RandomType


class TestRandomType(unittest.TestCase):
    """RandomType unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testRandomType(self):
        """Test RandomType"""
        # FIXME: construct object with mandatory attributes with example values
        # model = RandomType()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
