# flake8: noqa

"""
    General Synthesis

    # General Synthesis Service for Electronic Lab Notebooks (ELN)  ## Setup  ### Python  Recommended:  - [pyenv](https://github.com/pyenv/pyenv) - to manage Python versions - [pyenv-virtualenv](https://github.com/pyenv/pyenv-virtualenv) - to manage virtual environments  ```sh pyenv install 3.9.10 pyenv virtualenv 3.9.10 gensyn-eln pyenv local gensyn-eln pip install --upgrade pip pip install -r requirements.txt ```  ## Running  Ensure Ray is running:  ```sh ray start --head ```  Run the service:  ```sh python src/main.py ```   # noqa: E501

    The version of the OpenAPI document: 0.0.1
    Contact: info@general-synthesis.com
    Generated by: https://openapi-generator.tech
"""


__version__ = "0.0.2"

# import ApiClient
from gensyn_client.api_client import ApiClient

# import Configuration
from gensyn_client.configuration import Configuration

# import exceptions
from gensyn_client.exceptions import OpenApiException
from gensyn_client.exceptions import ApiAttributeError
from gensyn_client.exceptions import ApiTypeError
from gensyn_client.exceptions import ApiValueError
from gensyn_client.exceptions import ApiKeyError
from gensyn_client.exceptions import ApiException
