"""
    General Synthesis

    # General Synthesis Service for Electronic Lab Notebooks (ELN)  ## Setup  ### Python  Recommended:  - [pyenv](https://github.com/pyenv/pyenv) - to manage Python versions - [pyenv-virtualenv](https://github.com/pyenv/pyenv-virtualenv) - to manage virtual environments  ```sh pyenv install 3.9.10 pyenv virtualenv 3.9.10 gensyn-eln pyenv local gensyn-eln pip install --upgrade pip pip install -r requirements.txt ```  ## Running  Ensure Ray is running:  ```sh ray start --head ```  Run the service:  ```sh python src/main.py ```   # noqa: E501

    The version of the OpenAPI document: 0.0.1
    Contact: info@general-synthesis.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from gensyn_client.api_client import ApiClient, Endpoint as _Endpoint
from gensyn_client.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)


class AugmentationApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client
        self.randomize_smiles_endpoint = _Endpoint(
            settings={
                'response_type': (bool, date, datetime, dict, float, int, list, str, none_type,),
                'auth': [
                    'APIKeyHeader'
                ],
                'endpoint_path': '/augmentation/randomize_smiles/{smiles}',
                'operation_id': 'randomize_smiles',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'smiles',
                    'count',
                    'random_type',
                    'isomeric_smiles',
                ],
                'required': [
                    'smiles',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'smiles':
                        (str,),
                    'count':
                        (int,),
                    'random_type':
                        (bool, date, datetime, dict, float, int, list, str, none_type,),
                    'isomeric_smiles':
                        (bool,),
                },
                'attribute_map': {
                    'smiles': 'smiles',
                    'count': 'count',
                    'random_type': 'random_type',
                    'isomeric_smiles': 'isomeric_smiles',
                },
                'location_map': {
                    'smiles': 'path',
                    'count': 'query',
                    'random_type': 'query',
                    'isomeric_smiles': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )

    def randomize_smiles(
        self,
        smiles,
        **kwargs
    ):
        """Randomize Smiles  # noqa: E501

        Generate N random SMILES (best effort), given a SMILES description of an exemplar molecule.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.randomize_smiles(smiles, async_req=True)
        >>> result = thread.get()

        Args:
            smiles (str): A SMILES molecule description

        Keyword Args:
            count (int): The number of random SMILES to generate. [optional] if omitted the server will use the default value of 1
            random_type (bool, date, datetime, dict, float, int, list, str, none_type): The type of randomization to perform. [optional]
            isomeric_smiles (bool): If True, returns the canonical isomeric SMILES. [optional] if omitted the server will use the default value of True
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            bool, date, datetime, dict, float, int, list, str, none_type
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['smiles'] = \
            smiles
        return self.randomize_smiles_endpoint.call_with_http_info(**kwargs)

