"""
    General Synthesis

    # General Synthesis Service for Electronic Lab Notebooks (ELN)  ## Setup  ### Python  Recommended:  - [pyenv](https://github.com/pyenv/pyenv) - to manage Python versions - [pyenv-virtualenv](https://github.com/pyenv/pyenv-virtualenv) - to manage virtual environments  ```sh pyenv install 3.9.10 pyenv virtualenv 3.9.10 gensyn-eln pyenv local gensyn-eln pip install --upgrade pip pip install -r requirements.txt ```  ## Running  Ensure Ray is running:  ```sh ray start --head ```  Run the service:  ```sh python src/main.py ```   # noqa: E501

    The version of the OpenAPI document: 0.0.1
    Contact: info@general-synthesis.com
    Generated by: https://openapi-generator.tech
"""


from setuptools import setup, find_packages  # noqa: H301

NAME = "gensyn-client"
VERSION = "0.0.2"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = [
  "urllib3 >= 1.25.3",
  "python-dateutil",
]

setup(
    name=NAME,
    version=VERSION,
    description="General Synthesis",
    author="General Synthesis",
    author_email="info@general-synthesis.com",
    url="",
    keywords=["OpenAPI", "OpenAPI-Generator", "General Synthesis"],
    python_requires=">=3.6",
    install_requires=REQUIRES,
    packages=find_packages(exclude=["test", "tests"]),
    include_package_data=True,
    long_description="""\
    # General Synthesis Service for Electronic Lab Notebooks (ELN)  ## Setup  ### Python  Recommended:  - [pyenv](https://github.com/pyenv/pyenv) - to manage Python versions - [pyenv-virtualenv](https://github.com/pyenv/pyenv-virtualenv) - to manage virtual environments  &#x60;&#x60;&#x60;sh pyenv install 3.9.10 pyenv virtualenv 3.9.10 gensyn-eln pyenv local gensyn-eln pip install --upgrade pip pip install -r requirements.txt &#x60;&#x60;&#x60;  ## Running  Ensure Ray is running:  &#x60;&#x60;&#x60;sh ray start --head &#x60;&#x60;&#x60;  Run the service:  &#x60;&#x60;&#x60;sh python src/main.py &#x60;&#x60;&#x60;   # noqa: E501
    """,
    long_description_content_type="text/markdown",
)
